| Title: | Supporting Objects for Sojourn Accelerometer Methods |
|---|---|
| Description: | Stores objects (e.g. neural networks) that are needed for using Sojourn accelerometer methods. For more information, see Lyden K, Keadle S, Staudenmayer J, & Freedson P (2014) <doi:10.1249/MSS.0b013e3182a42a2d>, Ellingson LD, Schwabacher IJ, Kim Y, Welk GJ, & Cook DB (2016) <doi:10.1249/MSS.0000000000000915>, and Hibbing PR, Ellingson LD, Dixon PM, & Welk GJ (2018) <doi:10.1249/MSS.0000000000001486>. |
| Authors: | Paul R. Hibbing [aut, cre], Kate Lyden [aut] |
| Maintainer: | Paul R. Hibbing <[email protected]> |
| License: | GPL-3 |
| Version: | 0.3.0 |
| Built: | 2026-06-03 09:19:16 UTC |
| Source: | https://github.com/cran/Sojourn.Data |
Uniaxial neural network for use in original triaxial Sojourn method
ALL.reg.nnALL.reg.nn
From print(ALL.reg.nn):
a 6-25-1 network with 207 weights inputs: X10. X25. X50. X75. X90. acf output(s): oxy.METS.calculated options were - skip-layer connections linear output units
Centering coefficients for uniaxial nnetinputs
centcent
A named numeric vector
Centering coefficients for triaxial nnetinputs
cent.1cent.1
A named numeric vector
Triaxial neural network for original Sojourn method
class.nnn.6class.nnn.6
From print(class.nnn.6):
a 22-25-4 network with 767 weights inputs: X50. X75. X90. acf X10.2 X25.2 X50.2 X75.2 X90.2 acf.2 X25.3 X50.3 X75.3 X90.3 acf.3 X10.vm X25.vm X50.vm X75.vm X90.vm acf.vm inact.durations output(s): train.6$act.type options were - skip-layer connections softmax modelling decay=0.03
Uniaxial neural network for use in the original uniaxial Sojourn method
reg.nnreg.nn
From print(reg.nn): a 6-25-1 network with 207 weights inputs: X10. X25. X50. X75. X90. acf output(s): oxy.METS.calculated options were - skip-layer connections linear output units
Scaling coefficients for uniaxial nnetinputs
scalscal
numeric vector of size 6
Scaling coefficients for triaxial nnetinputs
scal.1scal.1
numeric vector of size 25
Sojourn methods rely on large objects, which take up too much space in an ordinary package. Thus, the objects are stored in this data-only package, meant to complement the Sojourn package.
Data frame containing grid values for the youth Sojourn method
youth_gridsyouth_grids
data frame with 4 rows and 14 columns
Neural network for youth Sojourn method, taking activity count data from hip-worn monitors
youth_hipCountsyouth_hipCounts
From print(youth_hipCounts):
a 9-15-3 network with 198 weights inputs: Age SexM BMI VM_Q10 VM_Q25 VM_Q50 VM_Q75 VM_Q90 VM_lag1 output(s): .outcome options were - softmax modelling
Neural network for youth Sojourn method, taking raw accelerometer data from hip-worn monitors
youth_hipRawyouth_hipRaw
From print(youth_hipRaw):
a 9-20-3 network with 263 weights inputs: Age SexM BMI ENMO_Q10 ENMO_Q25 ENMO_Q50 ENMO_Q75 ENMO_Q90 ENMO_lag1 output(s): .outcome options were - softmax modelling decay=0.1
Neural network for youth Sojourn method, taking activity count data from non-dominant-wrist-worn monitors
youth_wristCountsyouth_wristCounts
From print(youth_wristCounts):
a 9-15-3 network with 198 weights inputs: Age SexM BMI VM_Q10 VM_Q25 VM_Q50 VM_Q75 VM_Q90 VM_lag1 output(s): .outcome options were - softmax modelling decay=0.1
Neural network for youth Sojourn method, taking raw accelerometer data from non-dominant-wrist-worn monitors
youth_wristRawyouth_wristRaw
From print(youth_wristRaw):
a 9-15-3 network with 198 weights inputs: Age SexM BMI ENMO_Q10 ENMO_Q25 ENMO_Q50 ENMO_Q75 ENMO_Q90 ENMO_lag1 output(s): .outcome options were - softmax modelling decay=0.1